.. include:: ../README.rst

Table of Contents
=================


.. toctree::
    :maxdepth: 5
    :hidden:

    self

.. toctree::
    :caption: IO Python Client Usage
    :maxdepth: 7

    quickstart


.. toctree::
    :caption: API Reference
    :maxdepth: 6

    feeds
    data
    groups



.. toctree::
    :caption: Other Links

    Download Library <https://github.com/adafruit/io-client-python/releases/latest>
    Adafruit IO <https://io.adafruit.com>
    Welcome to Adafruit IO Learning Guide <https://learn.adafruit.com/welcome-to-adafruit-io>
    Adafruit IO Support Forum <https://forums.adafruit.com/viewforum.php?f=56>
    Discord Chat (#adafruit-io) <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
